Gemini image generation (generateContent with the IMAGE modality).
Structs
- Google
Image Model - Image model backed by a Gemini image-capable language model.
Constants
- DEFAULT_
MAX_ IMAGES_ PER_ CALL - Default maximum images per call.
Functions
- image_
result - Converts the language model result of an image call into an image result:
image files become the generated images, the
googlemetadata gains animagesarray and the token usage is summed.