Module image

Module image 

Gemini image generation (generateContent with the IMAGE modality).

Structs

GoogleImageModel
Image model backed by a Gemini image-capable language model.

Constants

DEFAULT_MAX_IMAGES_PER_CALL
Default maximum images per call.

Functions

image_result
Converts the language model result of an image call into an image result: image files become the generated images, the google metadata gains an images array and the token usage is summed.